#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun May 17 2020
@author: Stephan Kelm
"""
import os
import matplotlib.pyplot as plt
import pandas as pd

#filter the yPlus functionObject output
def getPatch(case, patchname): 
    header = ('time','patch','min', 'max', 'average')
    df_yplus = pd.read_csv(os.path.join(os.getcwd(),case,'yPlus','0','yPlus.dat'), skiprows=2, sep='\t',  names=header, engine='python')  #index_col=0,
    
    removePatches=[]
    for i in range(0, len(df_yplus['patch'])):
        if df_yplus['patch'][i] != patchname:
            removePatches.append(df_yplus.index[i])
            
    df_yplus.drop(removePatches, inplace=True)
    df_yplus.index=df_yplus['time']
    return df_yplus

#compute mass balance
def getMassBalance(case):
    header=('time','H2O','HE', 'AIR')
    df_massBalance = pd.read_csv(os.path.join(os.getcwd(),case,'intSpecieMass','0','volFieldValue.dat'), skiprows=4, sep='\t',  names=header, engine='python')  #index_col=0,
    df_massIn = pd.read_csv(os.path.join(os.getcwd(),case,'patchMassFlux','0','surfaceFieldValue.dat'), skiprows=4, sep='\t',  names=header, engine='python')  #index_col=0,
    df_cond = pd.read_csv(os.path.join(os.getcwd(),case,'wallCondRate','0','surfaceFieldValue.dat'), skiprows=4, sep='\t',  names=('time','H2O'), engine='python')  #index_col=0,

    # integrate in and outgoing fluxes
    HeInj, AirInj, H2OInj, H2OCond = [],[],[],[]

    for i in range(0,len(df_massIn['time'])):
        n= i-1 
        if (i == 0):
            HeInj.append(0.0)
            AirInj.append(0.0)
            H2OInj.append(0.0)
            H2OCond.append(0.0)
        else:
            HeInj.append(HeInj[n] + (df_massIn['time'][i]-df_massIn['time'][n])*(df_massIn['HE'][n]+df_massIn['HE'][i])/2)
            AirInj.append(AirInj[n] + (df_massIn['time'][i]-df_massIn['time'][n])*(df_massIn['AIR'][n]+df_massIn['AIR'][i])/2)
            H2OInj.append(H2OInj[n] + (df_massIn['time'][i]-df_massIn['time'][n])*(df_massIn['H2O'][n]+df_massIn['H2O'][i])/2)
            H2OCond.append(H2OCond[n] + (df_cond['time'][i]-df_cond['time'][n])*(df_cond['H2O'][n]+df_cond['H2O'][i])/2)

    df_massBalance['HeInj'] = HeInj
    df_massBalance['AirInj'] = AirInj
    df_massBalance['H2OInj'] = H2OInj
    df_massBalance['H2OCond'] = H2OCond
        
    df_massBalance.index = df_massBalance['time']
    df_massBalance['AirError'] = df_massBalance['AIR']/(df_massBalance['AIR'].iloc[0]-df_massBalance['AirInj'])
    df_massBalance['H2OError'] = df_massBalance['H2O']/(df_massBalance['H2O'].iloc[0]-df_massBalance['H2OInj']+df_massBalance['H2OCond'])
    df_massBalance['HeError'] = (df_massBalance['HE'])/(df_massBalance['HE'].iloc[0]-df_massBalance['HeInj']+1e-20)

    return df_massBalance


#Import experimental data
df_exp = pd.read_csv(os.path.join(os.getcwd(),'referenceData','pressure_paper'), index_col=0,skiprows=0, sep=';', engine='python')

#Import injection rates
df_inj = pd.read_csv(os.path.join(os.getcwd(),'csv','transientInp_5deg'), index_col=0, skiprows=0, sep=';', engine='python')


### plotting
fig, (sub1, sub2, sub3, sub4) =  plt.subplots(nrows=4,ncols=1, sharex=True,squeeze= True, gridspec_kw={'height_ratios': [2, 10, 2, 2]}, figsize=(10,10),dpi=300)

# Plot mass flux history
#Import simulation integral condensation rate
header=('time','intCondRate')
df_sim = pd.read_csv(os.path.join(os.getcwd(),'postProcessing','wallCondRate','0','surfaceFieldValue.dat'), skiprows=4, sep='\t', index_col=0, names=header, engine='python')

sub1.plot(df_inj['mtotal[kg/s]']*df_inj['Ysteam']*1000*360/5,color = 'blue', linestyle = '-', label = 'steam inj. rate')
sub1.plot(df_sim['intCondRate']*-1000*360/6,color = 'blue', linestyle = '--', lw=0.5, label = 'steam cond rate')
sub1.plot(df_inj['mtotal[kg/s]']*df_inj['Yair']*1000*360/5,color = 'red', linestyle = '-', label = 'air inj. rate')
sub1.plot(df_inj['mtotal[kg/s]']*df_inj['Yhelium']*1000*360/5,color = 'orange', linestyle = '-', label = 'helium inj. rate')

sub1.set_xlim(0,20000)
sub1.set_ylim(0,15)
sub1.tick_params(direction='out', labelsize = 10)
sub1.grid(which='major', axis='both',color='#666666', linestyle='-', linewidth=0.5)
sub1.minorticks_on()
sub1.grid(which='minor', axis='both',color='#999999', linestyle='-', linewidth=0.5, alpha=0.2)
sub1.set_ylabel('inj. rate [g/s]', fontsize=10)
#sub2.set_xlabel('time [s]', fontsize=10)
sub1.legend(loc='upper right', fontsize=10)

# Plot pressure history
header=('time','p','T')
df_sim = pd.read_csv(os.path.join(os.getcwd(),'postProcessing','volAverage','0','volFieldValue.dat'), skiprows=4, sep='\t', index_col=0, names=header, engine='python')

sub2.plot(df_exp['Pressure [bar]'],color = 'black', linestyle = '--', label = 'experiment')
sub2.plot(df_sim['p']/1e5, color = 'blue', linestyle = '-', label = 'containmentFoam')

sub2.set_xlim(0,20000)
sub2.set_ylim(1,4)
sub2.tick_params(direction='out', labelsize = 10)
sub2.grid(which='major', axis='both',color='#666666', linestyle='-', linewidth=0.5)
sub2.minorticks_on()
sub2.grid(which='minor', axis='both',color='#999999', linestyle='-', linewidth=0.5, alpha=0.2)
#sub1.set_xlabel('time [s]', fontsize=10)
sub2.set_ylabel('vessel pressure [bar]', fontsize=10)
sub2.legend(loc='lower right', fontsize=10)



# Plot  y+ history
df_yplus=getPatch('postProcessing','INNER_COOLED_WALL')

sub3.plot(df_yplus['time'], df_yplus['average'], color = 'blue', linestyle = '-', linewidth=1.00, label = 'condensing wall')
#sub3.plot(df_sim['time'],df_sim['HE']/8.59221665e-03,color = 'green', linestyle = '-', linewidth=1.00, label = 'Helium')
sub3.legend(loc='upper right', fontsize=10)

sub3.set_xlim(0,20000)
#sub3.set_ylim(0,60)
sub3.grid(which='major', axis='both',color='#666666', linestyle='-', linewidth=0.5)
sub3.minorticks_on()
sub3.grid(which='minor', axis='both',color='#999999', linestyle='-', linewidth=0.5, alpha=0.2)
sub3.set_xlabel('time [s]', fontsize=10)
sub3.set_ylabel('ave $y^+$', fontsize=10)



#Plot the mass balance
df_massBalance = getMassBalance('postProcessing')

sub4.plot(df_massBalance['AirError'], color = 'red', linestyle = '-', linewidth=1.00, label = 'Air')
sub4.plot(df_massBalance['HeError'], color = 'blue', linestyle = '-', linewidth=1.00, label = 'Helium')
sub4.plot(df_massBalance['H2OError'], color = 'green', linestyle = '-', linewidth=1.00, label = 'Steam')
sub4.legend(loc='upper right', fontsize=10)

sub4.grid(which='major', axis='both',color='#666666', linestyle='-', linewidth=0.5)
sub4.minorticks_on()
sub4.set_xlim(0,20000)
sub4.set_ylim(0.99,1.01)
sub4.grid(which='minor', axis='both',color='#999999', linestyle='-', linewidth=0.5, alpha=0.2)
sub4.set_xlabel('time [s]', fontsize=10)
sub4.set_ylabel('rel. error $m/(m_0+m_{inj})$', fontsize=10)

fig.savefig('evaluation_TOSQAN_ISP47.png')
