## This script was designed to be applied along with the use of sampled surfaces
## stored as separate vtk files in time folders.
## The script merges all vtk files in a time folder into a single binary vtp file
## named with the time stamp. This reduces the file size significantly.
## The resulting vtp files can be processed as individually in paraView.
## To load the complete time series open the pvd file 

## created: Stephan Kelm
## date:    Oct. 10th 2020

import os
from paraview.simple import *

def writePVD(dataDir):
    f = open('timeSteps.pvd', 'w')
    f.write('<?xml version=\"1.0\"?>\n')
    f.write('<VTKFile type=\"Collection\" version=\"1.0\" byte_order=\"LittleEndian\" header_type=\"UInt64\" compressor=\"vtkLZMADataCompressor\">\n')
    f.write('\t<Collection>\n')
    listVTPFiles = [_ for _ in os.listdir(dataDir) if _.endswith('.vtp')]
    for file in listVTPFiles:
        time = float(file.split('_')[1][:-4])
        f.write('\t\t<DataSet timestep=\"'+ str(time) +'\"\t part=\"0\"\t file=\"' + os.path.join(dataDir, file) +'\"/>\n')
    f.write('\t</Collection>\n')
    f.write('</VTKFile>\n')
    f.close()

dataDir = os.path.join('.','postProcessing','coProcessingSurfaces')

timeDirs = [dI for dI in os.listdir(dataDir) if os.path.isdir(os.path.join(dataDir,dI))]
timeDirs.sort()

for folder in timeDirs:    
    try:
        files = os.listdir(os.path.join(dataDir,folder))
        timeStamp= str((round(float(folder),1))).zfill(8)  # StK: one digit is allowed
        print(' --> processing time step', folder)
        vtkReader = []
    
        for file in files:
            vtkReader.append(LegacyVTKReader(FileNames=[os.path.join(dataDir, folder, file)]))
            
        appendAttributes1 = AppendAttributes(Input=vtkReader)

        fileName = os.path.join(dataDir,'time_'+timeStamp+'.vtp')
        SaveData(fileName, proxy=appendAttributes1, EncodeAppendedData=1, CompressorType='LZMA')
            
        os.system('rm -r {}'.format(os.path.join(dataDir,folder)))
        
    except ValueError:
        print('folder', folder, 'does not contain vtk files')
 
writePVD(dataDir)
